package goatcounter

// Blacklist from https://github.com/matomo-org/referrer-spam-blacklist
// Last update: 1437044 16 Jan 2020
//
// curl -s https://raw.githubusercontent.com/matomo-org/referrer-spam-blacklist/master/spammers.txt | sort -u | sed 's/.*/\t"\0": {},/'
var blacklist = map[string]struct{}{
	// Not spam, but we never really want to accept requests from localhost.
	"localhost": {},

	"01casino-x.ru":                        {},
	"033nachtvandeliteratuur.nl":           {},
	"03e.info":                             {},
	"03p.info":                             {},
	"0n-line.tv":                           {},
	"1-99seo.com":                          {},
	"1-best-seo.com":                       {},
	"1-free-share-buttons.com":             {},
	"100-reasons-for-seo.com":              {},
	"100dollars-seo.com":                   {},
	"100searchengines.com":                 {},
	"12-reasons-for-seo.net":               {},
	"12masterov.com":                       {},
	"12u.info":                             {},
	"15-reasons-for-seo.com":               {},
	"1kreditzaim.ru":                       {},
	"1pamm.ru":                             {},
	"1st-urist.ru":                         {},
	"1webmaster.ml":                        {},
	"1winru.ru":                            {},
	"1xbet-entry.ru":                       {},
	"1xslot-casino.site":                   {},
	"1xslot.site":                          {},
	"1xslots-africa.site":                  {},
	"1xslots-brasil.site":                  {},
	"1xslots-casino.site":                  {},
	"1xslots.africa":                       {},
	"1xslots.site":                         {},
	"2-best-seo.com":                       {},
	"2-easy.xyz":                           {},
	"2-go-now.xyz":                         {},
	"24chasa.bg":                           {},
	"24h.doctor":                           {},
	"24x7-server-support.site":             {},
	"2your.site":                           {},
	"3-best-seo.com":                       {},
	"3-letter-domains.net":                 {},
	"3dgame3d.com":                         {},
	"3waynetworks.com":                     {},
	"4-best-seo.com":                       {},
	"40momporntube.com":                    {},
	"4inn.ru":                              {},
	"4istoshop.com":                        {},
	"4webmasters.org":                      {},
	"4xcasino.ru":                          {},
	"5-best-seo.com":                       {},
	"5-steps-to-start-business.com":        {},
	"5elementov.ru":                        {},
	"5forex.ru":                            {},
	"6-best-seo.com":                       {},
	"69-13-59.ru":                          {},
	"6hopping.com":                         {},
	"7-best-seo.com":                       {},
	"70casino.online":                      {},
	"7kop.ru":                              {},
	"7makemoneyonline.com":                 {},
	"7milliondollars.com":                  {},
	"7zap.com":                             {},
	"8-best-seo.com":                       {},
	"8xv8.com":                             {},
	"9-best-seo.com":                       {},
	"99-reasons-for-seo.com":               {},
	"QIWI.xyz":                             {},
	"a-elita.in.ua":                        {},
	"abcdefh.xyz":                          {},
	"abcdeg.xyz":                           {},
	"abclauncher.com":                      {},
	"acads.net":                            {},
	"acarreo.ru":                           {},
	"account-my1.xyz":                      {},
	"actualremont.ru":                      {},
	"acunetix-referrer.com":                {},
	"adanih.com":                           {},
	"adcash.com":                           {},
	"adelachrist.top":                      {},
	"adf.ly":                               {},
	"adpostmalta.com":                      {},
	"adrenalinebot.net":                    {},
	"adrenalinebot.ru":                     {},
	"adspart.com":                          {},
	"adtiger.tk":                           {},
	"adventureparkcostarica.com":           {},
	"adviceforum.info":                     {},
	"advokateg.xyz":                        {},
	"aerodizain.com":                       {},
	"aerotour.ru":                          {},
	"affiliate-programs.biz":               {},
	"affordablewebsitesandmobileapps.com":  {},
	"afora.ru":                             {},
	"agro-gid.com":                         {},
	"agtl.com.ua":                          {},
	"ahrefs.com":                           {},
	"ai-seo-services.com":                  {},
	"aibolita.com":                         {},
	"aidarmebel.kz":                        {},
	"aitiman.ae":                           {},
	"akuhni.by":                            {},
	"albuteroli.com":                       {},
	"alcobutik24.com":                      {},
	"alexsander.ch":                        {},
	"alfabot.xyz":                          {},
	"alibestsale.com":                      {},
	"aliexsale.ru":                         {},
	"alinabaniecka.pl":                     {},
	"alkanfarma.org":                       {},
	"all-news.kz":                          {},
	"all4bath.ru":                          {},
	"allcryptonews.com":                    {},
	"allergick.com":                        {},
	"allergija.com":                        {},
	"allknow.info":                         {},
	"allmarketsnewdayli.gdn":               {},
	"allnews.md":                           {},
	"allnews24.in":                         {},
	"allproblog.com":                       {},
	"allvacancy.ru":                        {},
	"allwomen.info":                        {},
	"allwrighter.ru":                       {},
	"alma-mramor.com.ua":                   {},
	"alp-rk.ru":                            {},
	"alphaopt24.ru":                        {},
	"alpharma.net":                         {},
	"altermix.ua":                          {},
	"amazon-seo-service.com":               {},
	"amos-kids.ru":                         {},
	"amp-project.pro":                      {},
	"amt-k.ru":                             {},
	"amtel-vredestein.com":                 {},
	"amylynnandrews.xyz":                   {},
	"anabolics.shop":                       {},
	"anal-acrobats.hol.es":                 {},
	"analytics-ads.xyz":                    {},
	"anapa-inns.ru":                        {},
	"android-style.com":                    {},
	"animalphotos.xyz":                     {},
	"animenime.ru":                         {},
	"annaeydlish.top":                      {},
	"anticrawler.org":                      {},
	"antiguabarbuda.ru":                    {},
	"antonovich-design.com.ua":             {},
	"apollon-market-url.org":               {},
	"applepharma.ru":                       {},
	"apteka-doc.ru":                        {},
	"apteka-pharm.ru":                      {},
	"arabic-poetry.com":                    {},
	"arendadogovor.ru":                     {},
	"arendakvartir.kz":                     {},
	"arendovalka.xyz":                      {},
	"argo-visa.ru":                         {},
	"arkkivoltti.net":                      {},
	"artblog.top":                          {},
	"artclipart.ru":                        {},
	"artdeko.info":                         {},
	"artpaint-market.ru":                   {},
	"artparquet.ru":                        {},
	"artpress.top":                         {},
	"arturs.moscow":                        {},
	"aruplighting.com":                     {},
	"ask-yug.com":                          {},
	"asupro.com":                           {},
	"asynt.net":                            {},
	"atleticpharm.org":                     {},
	"atyks.ru":                             {},
	"auto-b2b-seo-service.com":             {},
	"auto-complex.by":                      {},
	"auto-kia-fulldrive.ru":                {},
	"auto-seo-service.org":                 {},
	"autoblog.org.ua":                      {},
	"autofuct.ru":                          {},
	"automobile-spec.com":                  {},
	"autoseo-service.org":                  {},
	"autoseo-traffic.com":                  {},
	"autoseotips.com":                      {},
	"autoservic.by":                        {},
	"autovideobroadcast.com":               {},
	"avcoast.com":                          {},
	"aviaseller.su":                        {},
	"aviva-limoux.com":                     {},
	"avkzarabotok.info":                    {},
	"avtointeres.ru":                       {},
	"avtorskoe-vino.ru":                    {},
	"avtovykup.kz":                         {},
	"aworlds.com":                          {},
	"axcus.top":                            {},
	"azartclub.org":                        {},
	"azbukafree.com":                       {},
	"azlex.uz":                             {},
	"backlinks-fast-top.com":               {},
	"baixar-musicas-gratis.com":            {},
	"baladur.ru":                           {},
	"balakhna.online":                      {},
	"balayazh.com":                         {},
	"balitouroffice.com":                   {},
	"balkanfarma.org":                      {},
	"bankhummer.co":                        {},
	"barbarahome.top":                      {},
	"bard-real.com.ua":                     {},
	"batut-fun.ru":                         {},
	"bavariagid.de":                        {},
	"beachtoday.ru":                        {},
	"beauty-lesson.com":                    {},
	"beclean-nn.ru":                        {},
	"bedroomlighting.us":                   {},
	"belreferatov.net":                     {},
	"beremenyashka.com":                    {},
	"best-deal-hdd.pro":                    {},
	"best-mam.ru":                          {},
	"best-ping-service-usa.blue":           {},
	"best-printmsk.ru":                     {},
	"best-seo-offer.com":                   {},
	"best-seo-software.xyz":                {},
	"best-seo-solution.com":                {},
	"bestbookclub.ru":                      {},
	"bestfortraders.com":                   {},
	"bestmobilityscooterstoday.com":        {},
	"bestofferhddbyt.info":                 {},
	"bestofferhddeed.info":                 {},
	"bestvpnrating.com":                    {},
	"bestwebsitesawards.com":               {},
	"betterhealthbeauty.com":               {},
	"bettorschool.ru":                      {},
	"bez-zabora.ru":                        {},
	"bezprostatita.com":                    {},
	"bhf.vc":                               {},
	"bif-ru.info":                          {},
	"biglistofwebsites.com":                {},
	"billiard-classic.com.ua":              {},
	"billyblog.online":                     {},
	"bin-brokers.com":                      {},
	"binokna.ru":                           {},
	"bio-market.kz":                        {},
	"biplanecentre.ru":                     {},
	"bird1.ru":                             {},
	"bitcoin-ua.top":                       {},
	"biteg.xyz":                            {},
	"bitniex.com":                          {},
	"biz-law.ru":                           {},
	"bizru.info":                           {},
	"bki24.info":                           {},
	"black-friday.ga":                      {},
	"blackhatworth.com":                    {},
	"blog100.org":                          {},
	"blog2019.top":                         {},
	"blog2019.xyz":                         {},
	"blog4u.top":                           {},
	"blogking.top":                         {},
	"bloglag.com":                          {},
	"blogseo.xyz":                          {},
	"blogstar.fun":                         {},
	"blogtotal.de":                         {},
	"blogua.org":                           {},
	"blue-square.biz":                      {},
	"bluerobot.info":                       {},
	"bo-vtb24.ru":                          {},
	"boltalko.xyz":                         {},
	"boltushkiclub.ru":                     {},
	"bonkers.name":                         {},
	"bonus-spasibo-sberbank.ru":            {},
	"bonus-vtb.ru":                         {},
	"books-top.com":                        {},
	"boostmyppc.com":                       {},
	"botamycos.fr":                         {},
	"bottraffic4free.host":                 {},
	"bpro1.top":                            {},
	"brakehawk.com":                        {},
	"brateg.xyz":                           {},
	"brauni.com.ua":                        {},
	"bravica.biz":                          {},
	"bravica.com":                          {},
	"bravica.me":                           {},
	"bravica.net":                          {},
	"bravica.news":                         {},
	"bravica.online":                       {},
	"bravica.pro":                          {},
	"bravica.ru":                           {},
	"bravica.su":                           {},
	"break-the-chains.com":                 {},
	"brickmaster.pro":                      {},
	"brillianty.info":                      {},
	"brk-rti.ru":                           {},
	"brothers-smaller.ru":                  {},
	"brusilov.ru":                          {},
	"bsell.ru":                             {},
	"btcnix.com":                           {},
	"btt-club.pro":                         {},
	"budilneg.xyz":                         {},
	"budmavtomatika.com.ua":                {},
	"bufetout.ru":                          {},
	"buhproffi.ru":                         {},
	"buildnw.ru":                           {},
	"buildwithwendy.com":                   {},
	"buketeg.xyz":                          {},
	"bukleteg.xyz":                         {},
	"bulgaria-web-developers.com":          {},
	"bur-rk.ru":                            {},
	"burger-imperia.com":                   {},
	"burn-fat.ga":                          {},
	"business-online-sberbank.ru":          {},
	"buttons-for-website.com":              {},
	"buttons-for-your-website.com":         {},
	"buy-cheap-online.info":                {},
	"buy-cheap-pills-order-online.com":     {},
	"buy-forum.ru":                         {},
	"buy-meds24.com":                       {},
	"buynorxx.com":                         {},
	"buypillsonline24h.com":                {},
	"buypuppies.ca":                        {},
	"call-of-duty.info":                    {},
	"cancerfungus.com":                     {},
	"candida-international.blogspot.com":   {},
	"candida-society.org.uk":               {},
	"carder.me":                            {},
	"carder.tv":                            {},
	"cardiosport.com.ua":                   {},
	"cardsdumps.com":                       {},
	"carezi.com":                           {},
	"carivka.com.ua":                       {},
	"carscrim.com":                         {},
	"cartechnic.ru":                        {},
	"cashforum.cc":                         {},
	"casino-v.site":                        {},
	"casino-vulkane.com":                   {},
	"casino-x.host":                        {},
	"catterybengal.com":                    {},
	"cattyhealth.com":                      {},
	"cazino-v.online":                      {},
	"cazino-v.ru":                          {},
	"ccfullzshop.com":                      {},
	"cenokos.ru":                           {},
	"cenoval.ru":                           {},
	"cezartabac.ro":                        {},
	"chainii.ru":                           {},
	"chatroulette.life":                    {},
	"chcu.net":                             {},
	"cheap-trusted-backlinks.com":          {},
	"cheapkeys.ovh":                        {},
	"cheappills24h.com":                    {},
	"chelyabinsk.dienai.ru":                {},
	"chinese-amezon.com":                   {},
	"chip35.ru":                            {},
	"chizhik-2.ru":                         {},
	"ci.ua":                                {},
	"cityadspix.com":                       {},
	"citybur.ru":                           {},
	"cityreys.ru":                          {},
	"civilwartheater.com":                  {},
	"cleandom.in.ua":                       {},
	"cleaningservices.kiev.ua":             {},
	"clicksor.com":                         {},
	"climate.by":                           {},
	"clothing-deal.club":                   {},
	"club-lukojl.ru":                       {},
	"coderstate.com":                       {},
	"codysbbq.com":                         {},
	"coffeemashiny.ru":                     {},
	"coinswitch.cash":                      {},
	"columb.net.ua":                        {},
	"commerage.ru":                         {},
	"comp-pomosch.ru":                      {},
	"compliance-alex.xyz":                  {},
	"compliance-alexa.xyz":                 {},
	"compliance-andrew.xyz":                {},
	"compliance-barak.xyz":                 {},
	"compliance-brian.xyz":                 {},
	"compliance-don.xyz":                   {},
	"compliance-donald.xyz":                {},
	"compliance-elena.xyz":                 {},
	"compliance-fred.xyz":                  {},
	"compliance-george.xyz":                {},
	"compliance-irvin.xyz":                 {},
	"compliance-ivan.xyz":                  {},
	"compliance-john.top":                  {},
	"compliance-julianna.top":              {},
	"computer-remont.ru":                   {},
	"conciergegroup.org":                   {},
	"concretepol.com":                      {},
	"connectikastudio.com":                 {},
	"constanceonline.top":                  {},
	"cookie-law-enforcement-aa.xyz":        {},
	"cookie-law-enforcement-bb.xyz":        {},
	"cookie-law-enforcement-cc.xyz":        {},
	"cookie-law-enforcement-dd.xyz":        {},
	"cookie-law-enforcement-ee.xyz":        {},
	"cookie-law-enforcement-ff.xyz":        {},
	"cookie-law-enforcement-gg.xyz":        {},
	"cookie-law-enforcement-hh.xyz":        {},
	"cookie-law-enforcement-ii.xyz":        {},
	"cookie-law-enforcement-jj.xyz":        {},
	"cookie-law-enforcement-kk.xyz":        {},
	"cookie-law-enforcement-ll.xyz":        {},
	"cookie-law-enforcement-mm.xyz":        {},
	"cookie-law-enforcement-nn.xyz":        {},
	"cookie-law-enforcement-oo.xyz":        {},
	"cookie-law-enforcement-pp.xyz":        {},
	"cookie-law-enforcement-qq.xyz":        {},
	"cookie-law-enforcement-rr.xyz":        {},
	"cookie-law-enforcement-ss.xyz":        {},
	"cookie-law-enforcement-tt.xyz":        {},
	"cookie-law-enforcement-uu.xyz":        {},
	"cookie-law-enforcement-vv.xyz":        {},
	"cookie-law-enforcement-ww.xyz":        {},
	"cookie-law-enforcement-xx.xyz":        {},
	"cookie-law-enforcement-yy.xyz":        {},
	"cookie-law-enforcement-zz.xyz":        {},
	"cool-mining.com":                      {},
	"copyrightclaims.org":                  {},
	"copyrightinstitute.org":               {},
	"coral-info.com":                       {},
	"cosmediqueresults.com":                {},
	"covadhosting.biz":                     {},
	"coverage-my.com":                      {},
	"cp24.com.ua":                          {},
	"crazy-mining.org":                     {},
	"credit-card-tinkoff.ru":               {},
	"credit-cards-online24.ru":             {},
	"credit.co.ua":                         {},
	"crypto-bear.com":                      {},
	"crypto-mining.club":                   {},
	"curenaturalicancro.com":               {},
	"curenaturalicancro.nl":                {},
	"customsua.com.ua":                     {},
	"cyber-monday.ga":                      {},
	"dacha-svoimi-rukami.com":              {},
	"dailyrank.net":                        {},
	"dailyseo.xyz":                         {},
	"dailystorm.ru":                        {},
	"damianis.ru":                          {},
	"darknet-hydra-onion.biz":              {},
	"darknetsitesguide.com":                {},
	"darleneblog.online":                   {},
	"darodar.com":                          {},
	"dav.kz":                               {},
	"dawlenie.com":                         {},
	"dbutton.net":                          {},
	"dcdcapital.com":                       {},
	"deart-13.ru":                          {},
	"deirdre.top":                          {},
	"delfin-aqua.com.ua":                   {},
	"deluxewatch.su":                       {},
	"demenageur.com":                       {},
	"dengi-v-kredit.in.ua":                 {},
	"denisecarey.top":                      {},
	"deniseconnie.top":                     {},
	"dent-home.ru":                         {},
	"dentuled.net":                         {},
	"dermatovenerologiya.com":              {},
	"descargar-musica-gratis.net":          {},
	"detailedvideos.com":                   {},
	"detskie-konstruktory.ru":              {},
	"deutsche-poesie.com":                  {},
	"dev-seo.blog":                         {},
	"diatelier.ru":                         {},
	"dicru.info":                           {},
	"dienai.ru":                            {},
	"diplomas-ru.com":                      {},
	"dipstar.org":                          {},
	"discounttaxi.kz":                      {},
	"distonija.com":                        {},
	"divan-dekor.com.ua":                   {},
	"dividendo.ru":                         {},
	"djekxa.ru":                            {},
	"djonwatch.ru":                         {},
	"dktr.ru":                              {},
	"dna-sklad.ru":                         {},
	"dnmetall.ru":                          {},
	"docs4all.com":                         {},
	"docsarchive.net":                      {},
	"docsportal.net":                       {},
	"doctornadezhda.ru":                    {},
	"documentbase.net":                     {},
	"documentserver.net":                   {},
	"documentsite.net":                     {},
	"dodge-forum.eu":                       {},
	"doggyhealthy.com":                     {},
	"dogovorpodryada.ru":                   {},
	"dogsrun.net":                          {},
	"dojki-devki.ru":                       {},
	"dojki-hd.com":                         {},
	"dom-international.ru":                 {},
	"domain-tracker.com":                   {},
	"domashniy-hotel.ru":                   {},
	"domashniy-recepti.ru":                 {},
	"dominateforex.ml":                     {},
	"domination.ml":                        {},
	"dommdom.com":                          {},
	"domovozik.ru":                         {},
	"dompechey.by":                         {},
	"domsadiogorod.ru":                     {},
	"doska-vsem.ru":                        {},
	"dostavka-v-krym.com":                  {},
	"dosugrostov.site":                     {},
	"doxyporno.com":                        {},
	"doxysexy.com":                         {},
	"draniki.org":                          {},
	"dreamland-bg.com":                     {},
	"drev.biz":                             {},
	"drugs-no-rx.info":                     {},
	"drugstoreforyou.com":                  {},
	"drupa.com":                            {},
	"dspautomations.com":                   {},
	"duitbux.info":                         {},
	"dumpsccshop.com":                      {},
	"dvk-stroi.ru":                         {},
	"dvr.biz.ua":                           {},
	"dzinerstudio.com":                     {},
	"e-buyeasy.com":                        {},
	"e-commerce-seo.com":                   {},
	"e-commerce-seo1.com":                  {},
	"e-stroymart.kz":                       {},
	"eaptekaplus.ru":                       {},
	"earn-from-articles.com":               {},
	"earnian-money.info":                   {},
	"easycommerce.cf":                      {},
	"ecblog.xyz":                           {},
	"ecommerce-seo.org":                    {},
	"ecomp3.ru":                            {},
	"econom.co":                            {},
	"edakgfvwql.ru":                        {},
	"edmed-sonline.com":                    {},
	"educhess.ru":                          {},
	"edudocs.net":                          {},
	"eduinfosite.com":                      {},
	"eduserver.net":                        {},
	"ege-essay.ru":                         {},
	"ege-krasnoyarsk.ru":                   {},
	"egovaleo.it":                          {},
	"ek-invest.ru":                         {},
	"ekatalog.xyz":                         {},
	"eko-gazon.ru":                         {},
	"ekoproekt-kr.ru":                      {},
	"ekto.ee":                              {},
	"eldoradorent.az":                      {},
	"electric-blue-industries.com":         {},
	"elegante-vitrage.ru":                  {},
	"elektrikovich.ru":                     {},
	"elementspluss.ru":                     {},
	"elenatkachenko.com.ua":                {},
	"elentur.com.ua":                       {},
	"elizabethbruno.top":                   {},
	"ellemarket.com":                       {},
	"elmifarhangi.com":                     {},
	"elvel.com.ua":                         {},
	"emctestlab.ru":                        {},
	"emerson-rus.ru":                       {},
	"empire-market.org":                    {},
	"empiremarket-link.org":                {},
	"energomash.net":                       {},
	"energysexy.com":                       {},
	"englishtopic.ru":                      {},
	"enter-unicredit.ru":                   {},
	"epicdiving.com":                       {},
	"eraglass.com":                         {},
	"eric-artem.com":                       {},
	"eropho.com":                           {},
	"eropho.net":                           {},
	"erot.co":                              {},
	"es-pfrf.ru":                           {},
	"escort-russian.com":                   {},
	"eskei83.com":                          {},
	"esoterikforum.at":                     {},
	"este-line.com.ua":                     {},
	"etairikavideo.gr":                     {},
	"etehnika.com.ua":                      {},
	"etotupo.ru":                           {},
	"ets-2-mod.ru":                         {},
	"eu-cookie-law-enforcement2.xyz":       {},
	"eurocredit.xyz":                       {},
	"euromasterclass.ru":                   {},
	"europages.com.ru":                     {},
	"eurosamodelki.ru":                     {},
	"event-tracking.com":                   {},
	"eventiyahall.ru":                      {},
	"exdocsfiles.com":                      {},
	"expediacustomerservicenumber.online":  {},
	"expert-find.ru":                       {},
	"express-vyvoz.ru":                     {},
	"eyes-on-you.ga":                       {},
	"f1nder.org":                           {},
	"fainaidea.com":                        {},
	"falco3d.com":                          {},
	"falcoware.com":                        {},
	"fanoboi.com":                          {},
	"fartunabest.ru":                       {},
	"fashiong.ru":                          {},
	"fast-wordpress-start.com":             {},
	"favoritki-msk.ru":                     {},
	"fazika.ru":                            {},
	"fbdownloader.com":                     {},
	"feminist.org.ua":                      {},
	"fialka.tomsk.ru":                      {},
	"fidalsa.de":                           {},
	"filesclub.net":                        {},
	"filesdatabase.net":                    {},
	"films2018.com":                        {},
	"filter-ot-zheleza.ru":                 {},
	"financial-simulation.com":             {},
	"finansov.info":                        {},
	"finder.cool":                          {},
	"findercarphotos.com":                  {},
	"firstblog.top":                        {},
	"fit-discount.ru":                      {},
	"fitodar.com.ua":                       {},
	"fix-website-errors.com":               {},
	"flexderek.com":                        {},
	"floating-share-buttons.com":           {},
	"flowertherapy.ru":                     {},
	"flyblog.xyz":                          {},
	"for-marketersy.info":                  {},
	"for-your.website":                     {},
	"forex-procto.ru":                      {},
	"forsex.info":                          {},
	"fortwosmartcar.pw":                    {},
	"forum69.info":                         {},
	"foxweber.com":                         {},
	"francaise-poesie.com":                 {},
	"frankofficial.ru":                     {},
	"frauplus.ru":                          {},
	"free-fb-traffic.com":                  {},
	"free-fbook-traffic.com":               {},
	"free-floating-buttons.com":            {},
	"free-games-download.falcoware.com":    {},
	"free-share-buttons.com":               {},
	"free-social-buttons.com":              {},
	"free-social-buttons.xyz":              {},
	"free-social-buttons7.xyz":             {},
	"free-traffic.xyz":                     {},
	"free-video-tool.com":                  {},
	"free-website-traffic.com":             {},
	"freenode.info":                        {},
	"freewhatsappload.com":                 {},
	"freewlan.info":                        {},
	"freshnails.com.ua":                    {},
	"fsalas.com":                           {},
	"fullzdumps.cc":                        {},
	"furniturehomewares.com":               {},
	"galblog.top":                          {},
	"game300.ru":                           {},
	"gandikapper.ru":                       {},
	"gatwick.ru":                           {},
	"gazel-72.ru":                          {},
	"gbh-invest.ru":                        {},
	"gearcraft.us":                         {},
	"gearsadspromo.club":                   {},
	"geliyballon.ru":                       {},
	"gelstate.ru":                          {},
	"generalporn.org":                      {},
	"geniusfood.co.uk":                     {},
	"georgeblog.online":                    {},
	"gepatit-info.top":                     {},
	"germes-trans.com":                     {},
	"get-clickize.info":                    {},
	"get-free-social-traffic.com":          {},
	"get-free-traffic-now.com":             {},
	"get-more-freeer-visitors.info":        {},
	"get-more-freeish-visitors.info":       {},
	"get-seo-help.com":                     {},
	"get-your-social-buttons.info":         {},
	"getaadsincome.info":                   {},
	"getadsincomely.info":                  {},
	"getfy-click.info":                     {},
	"getlamborghini.ga":                    {},
	"getpy-click.info":                     {},
	"getrichquick.ml":                      {},
	"getrichquickly.info":                  {},
	"gezlev.com.ua":                        {},
	"ghazel.ru":                            {},
	"ghostvisitor.com":                     {},
	"gidonline.one":                        {},
	"giftbig.ru":                           {},
	"girlporn.ru":                          {},
	"gkvector.ru":                          {},
	"glavprofit.ru":                        {},
	"global-smm.ru":                        {},
	"gobongo.info":                         {},
	"golden-praga.ru":                      {},
	"good-potolok.ru":                      {},
	"goodbyecellulite.ru":                  {},
	"goodhumor24.com":                      {},
	"goodprotein.ru":                       {},
	"google-liar.ru":                       {},
	"googlemare.com":                       {},
	"googlsucks.com":                       {},
	"gorgaz.info":                          {},
	"grafaman.ru":                          {},
	"greatblog.top":                        {},
	"greentechsy.com":                      {},
	"groshi-kredut.com.ua":                 {},
	"growth-hackingan.info":                {},
	"growth-hackingor.info":                {},
	"growth-hackingy.info":                 {},
	"gruzchiki24.ru":                       {},
	"guardlink.org":                        {},
	"guidetopetersburg.com":                {},
	"halefa.com":                           {},
	"handicapvantoday.com":                 {},
	"hankspring.xyz":                       {},
	"happysong.ru":                         {},
	"hard-porn.mobi":                       {},
	"havepussy.com":                        {},
	"hawaiisurf.com":                       {},
	"hd1080film.ru":                        {},
	"hdhc.site":                            {},
	"hdmoviecamera.net":                    {},
	"hdmoviecams.com":                      {},
	"headpharmacy.com":                     {},
	"healbio.ru":                           {},
	"healgastro.com":                       {},
	"healthhacks.ru":                       {},
	"hentai-manga.porn":                    {},
	"heroero.com":                          {},
	"hexometer.com":                        {},
	"hit-kino.ru":                          {},
	"holiday-shop.ru":                      {},
	"holistickenko.com":                    {},
	"holodkovich.com":                      {},
	"homeafrikalike.tk":                    {},
	"homemypicture.tk":                     {},
	"hongfanji.com":                        {},
	"hosting-tracker.com":                  {},
	"hotblognetwork.com":                   {},
	"hottour.com":                          {},
	"housedesigning.ru":                    {},
	"housediz.com":                         {},
	"housemilan.ru":                        {},
	"howopen.ru":                           {},
	"howtostopreferralspam.eu":             {},
	"hoztorg-opt.ru":                       {},
	"hseipaa.kz":                           {},
	"hulfingtonpost.com":                   {},
	"humanorightswatch.org":                {},
	"hundejo.com":                          {},
	"huntdown.info":                        {},
	"hvd-store.com":                        {},
	"hydra-2019.ru":                        {},
	"hydra-2020.online":                    {},
	"hydra-2020.ru":                        {},
	"hydra-guide.org":                      {},
	"hydra-new.online":                     {},
	"hydra-onion-faq.com":                  {},
	"hydra-shop.org":                       {},
	"hydra-site.ru":                        {},
	"hydra-vhod2020.com":                   {},
	"hydra-zerkalo20.com":                  {},
	"hydra2.market":                        {},
	"hydra2020market.com":                  {},
	"hydra2020onion.com":                   {},
	"hydra20onion.com":                     {},
	"hydra2use.com":                        {},
	"hydra2zahod.com":                      {},
	"hydraena.com":                         {},
	"hydrahow.com":                         {},
	"hydraland.net":                        {},
	"hydramarket2020.com":                  {},
	"hydraonion2019.net":                   {},
	"hydraruz-2020.com":                    {},
	"hydraruzonion2020.com":                {},
	"hydraruzxpnew4af.ink":                 {},
	"hydrauliczny.com":                     {},
	"hydrazerkalo2019.net":                 {},
	"hyip-zanoza.me":                       {},
	"i-spare.ru":                           {},
	"ib-homecredit.ru":                     {},
	"ib-rencredit.ru":                      {},
	"ico.re":                               {},
	"igadgetsworld.com":                    {},
	"igru-xbox.net":                        {},
	"ilikevitaly.com":                      {},
	"iloveitaly.ro":                        {},
	"iloveitaly.ru":                        {},
	"ilovevitaly.co":                       {},
	"ilovevitaly.com":                      {},
	"ilovevitaly.info":                     {},
	"ilovevitaly.org":                      {},
	"ilovevitaly.ru":                       {},
	"ilovevitaly.xyz":                      {},
	"iminent.com":                          {},
	"immigrational.info":                   {},
	"imperiafilm.ru":                       {},
	"impotentik.com":                       {},
	"in-sto.ru":                            {},
	"incanto.in.ua":                        {},
	"incitystroy.ru":                       {},
	"incomekey.net":                        {},
	"increasewwwtraffic.info":              {},
	"inet-shop.su":                         {},
	"infektsii.com":                        {},
	"infodocsportal.com":                   {},
	"infogame.name":                        {},
	"inform-ua.info":                       {},
	"inmoll.com":                           {},
	"insider.pro":                          {},
	"installspartners.com":                 {},
	"instasexyblog.com":                    {},
	"insultu-net.ru":                       {},
	"interferencer.ru":                     {},
	"intex-air.ru":                         {},
	"investpamm.ru":                        {},
	"iskalko.ru":                           {},
	"iskussnica.ru":                        {},
	"isotoner.com":                         {},
	"ispaniya-costa-blanca.ru":             {},
	"it-max.com.ua":                        {},
	"izamorfix.ru":                         {},
	"izhstrelok.ru":                        {},
	"jav-fetish.com":                       {},
	"jav-fetish.site":                      {},
	"jav-idol.com":                         {},
	"javcoast.com":                         {},
	"javlibrary.cc":                        {},
	"jeffbullas.xyz":                       {},
	"jjbabskoe.ru":                         {},
	"jobgirl24.ru":                         {},
	"jobius.com.ua":                        {},
	"josephineblog.top":                    {},
	"jumkite.com":                          {},
	"justkillingti.me":                     {},
	"justprofit.xyz":                       {},
	"kabbalah-red-bracelets.com":           {},
	"kabinet-5ka.ru":                       {},
	"kabinet-alfaclick.ru":                 {},
	"kabinet-binbank.ru":                   {},
	"kabinet-card-5ka.ru":                  {},
	"kabinet-click-alfabank.ru":            {},
	"kabinet-esia-gosuslugi.ru":            {},
	"kabinet-faberlic.ru":                  {},
	"kabinet-gosuslugi.ru":                 {},
	"kabinet-ipoteka-domclick.ru":          {},
	"kabinet-karta-5ka.ru":                 {},
	"kabinet-lk-megafon.ru":                {},
	"kabinet-lk-rt.ru":                     {},
	"kabinet-login-mts.ru":                 {},
	"kabinet-mil.ru":                       {},
	"kabinet-mos.ru":                       {},
	"kabinet-my-beeline.ru":                {},
	"kabinet-my-pochtabank.ru":             {},
	"kabinet-nalog.ru":                     {},
	"kabinet-online-bm.ru":                 {},
	"kabinet-online-open.ru":               {},
	"kabinet-online-rsb.ru":                {},
	"kabinet-online-rshb.ru":               {},
	"kabinet-online-sberbank.ru":           {},
	"kabinet-online-sovcombank.ru":         {},
	"kabinet-online-vtb.ru":                {},
	"kabinet-pfr.ru":                       {},
	"kabinet-pfrf.ru":                      {},
	"kabinet-platon.ru":                    {},
	"kabinet-qiwi.ru":                      {},
	"kabinet-tele2.ru":                     {},
	"kabinet-tinkoff.ru":                   {},
	"kabinet-tricolor.ru":                  {},
	"kabinet-ttk.ru":                       {},
	"kabinet-vtb24.ru":                     {},
	"kakablog.net":                         {},
	"kakadu-interior.com.ua":               {},
	"kakworldoftanks.ru":                   {},
	"kambasoft.com":                        {},
	"kamin-sam.ru":                         {},
	"kanakox.com":                          {},
	"karapuz.org.ua":                       {},
	"kazka.ru":                             {},
	"kazlenta.kz":                          {},
	"kazrent.com":                          {},
	"kerch.site":                           {},
	"kevblog.top":                          {},
	"keywords-monitoring-success.com":      {},
	"keywords-monitoring-your-success.com": {},
	"kharkov.ua":                           {},
	"kierowca-praca.pl":                    {},
	"kinnarimasajes.com":                   {},
	"kino-fun.ru":                          {},
	"kino-key.info":                        {},
	"kino2018.cc":                          {},
	"kinobum.org":                          {},
	"kinopolet.net":                        {},
	"kinosed.net":                          {},
	"kinostar.online":                      {},
	"kiyany-za-spravedluvist.com.ua":       {},
	"knigonosha.net":                       {},
	"kollekcioner.ru":                      {},
	"komp-pomosch.ru":                      {},
	"komputers-best.ru":                    {},
	"komukc.com.ua":                        {},
	"konkursov.net":                        {},
	"kozhakoshek.com":                      {},
	"kozhasobak.com":                       {},
	"kozhniebolezni.com":                   {},
	"krasivoe-hd.net":                      {},
	"krasnodar-avtolombard.ru":             {},
	"krasota-zdorovie.pw":                  {},
	"krasota.ru":                           {},
	"kredutu.com.ua":                       {},
	"kredytbank.com.ua":                    {},
	"kruiz-sochi.ru":                       {},
	"krumble-adsde.info":                   {},
	"krumble-adsen.info":                   {},
	"krumbleent-ads.info":                  {},
	"l2soft.eu":                            {},
	"lakiikraski.ru":                       {},
	"lalalove.ru":                          {},
	"laminat.com.ua":                       {},
	"landliver.org":                        {},
	"landoftracking.com":                   {},
	"laptop-4-less.com":                    {},
	"law-check-two.xyz":                    {},
	"law-enforcement-bot-ff.xyz":           {},
	"law-enforcement-check-three.xyz":      {},
	"law-enforcement-ee.xyz":               {},
	"law-six.xyz":                          {},
	"lawrenceblog.online":                  {},
	"laxdrills.com":                        {},
	"leboard.ru":                           {},
	"ledalfa.by":                           {},
	"ledx.by":                              {},
	"leeboyrussia.com":                     {},
	"legalrc.biz":                          {},
	"lerporn.info":                         {},
	"leto-dacha.ru":                        {},
	"lider82.ru":                           {},
	"lifespeaker.ru":                       {},
	"ligastavok-in.ru":                     {},
	"lindsayblog.online":                   {},
	"lipidofobia.com.br":                   {},
	"littleberry.ru":                       {},
	"livefixer.com":                        {},
	"livejournal.top":                      {},
	"livia-pache.ru":                       {},
	"livingroomdecoratingideas.website":    {},
	"lk-gosuslugi.ru":                      {},
	"lk-lk-rt.ru":                          {},
	"local-seo-for-multiple-locations.com": {},
	"login-tinkoff.ru":                     {},
	"logo-all.ru":                          {},
	"lolzteam.online":                      {},
	"lolzteam.org":                         {},
	"lotoflotto.ru":                        {},
	"loveorganic.ch":                       {},
	"lowpricesiterx.com":                   {},
	"lsex.xyz":                             {},
	"luckybull.io":                         {},
	"lukoilcard.ru":                        {},
	"lumb.co":                              {},
	"luton-invest.ru":                      {},
	"luxup.ru":                             {},
	"luxurybet.ru":                         {},
	"magicart.store":                       {},
	"magicdiet.gq":                         {},
	"magnetic-bracelets.ru":                {},
	"mainhunter.com":                       {},
	"makemoneyonline.com":                  {},
	"makeprogress.ga":                      {},
	"makler.org.ua":                        {},
	"maltadailypost.com":                   {},
	"mamylik.ru":                           {},
	"manimpotence.com":                     {},
	"manualterap.roleforum.ru":             {},
	"marathonbet-in.ru":                    {},
	"marblestyle.ru":                       {},
	"maridan.com.ua":                       {},
	"marinetraffic.com":                    {},
	"marjorieblog.online":                  {},
	"marketland.ml":                        {},
	"masterseek.com":                       {},
	"matomete.net":                         {},
	"matras.space":                         {},
	"mattgibson.us":                        {},
	"max-apprais.com":                      {},
	"maxinesamson.top":                     {},
	"maxxximoda.ru":                        {},
	"mebel-arts.com":                       {},
	"mebel-ekb.com":                        {},
	"mebel-iz-dereva.kiev.ua":              {},
	"mebelcomplekt.ru":                     {},
	"mebeldekor.com.ua":                    {},
	"meblieco.com":                         {},
	"med-dopomoga.com":                     {},
	"med-recept.ru":                        {},
	"med-zdorovie.com.ua":                  {},
	"medbrowse.info":                       {},
	"medic-al.ru":                          {},
	"medicaltranslate.ru":                  {},
	"medicineseasybuy.com":                 {},
	"meds-online24.com":                    {},
	"meduza-consult.ru":                    {},
	"megalit-d.ru":                         {},
	"megapolis-96.ru":                      {},
	"megatkani.ru":                         {},
	"melbet-in.ru":                         {},
	"meriton.ru":                           {},
	"metallo-konstruktsii.ru":              {},
	"metallosajding.ru":                    {},
	"meteocast.net":                        {},
	"mhp.su":                               {},
	"midnight.im":                          {},
	"mifepriston.net":                      {},
	"migronis.com":                         {},
	"mikozstop.com":                        {},
	"mikrocement.com.ua":                   {},
	"mikrozaim.site":                       {},
	"mikrozaym2you.ru":                     {},
	"minegam.com":                          {},
	"miningblack.net":                      {},
	"mirfairytale.ru":                      {},
	"mirobuvi.com.ua":                      {},
	"mirtorrent.net":                       {},
	"misselle.ru":                          {},
	"mksoap.ru":                            {},
	"mksport.ru":                           {},
	"mmdoors.ru":                           {},
	"mmm.lc":                               {},
	"mnogabukaff.net":                      {},
	"mobicover.com.ua":                     {},
	"mobilemedia.md":                       {},
	"mockupui.com":                         {},
	"modforwot.ru":                         {},
	"modnie-futbolki.net":                  {},
	"moe1.ru":                              {},
	"moinozhki.com":                        {},
	"moisadogorod.ru":                      {},
	"monetizationking.net":                 {},
	"money-for-placing-articles.com":       {},
	"money7777.info":                       {},
	"moneytop.ru":                          {},
	"moneyzzz.ru":                          {},
	"monicablog.xyz":                       {},
	"moon.market":                          {},
	"moonci.ru":                            {},
	"mosputana.info":                       {},
	"mosputana.top":                        {},
	"mosrif.ru":                            {},
	"mostbet-original.ru":                  {},
	"mostcool.top":                         {},
	"mostorgnerud.ru":                      {},
	"moy-dokument.com":                     {},
	"moy-evroopt.ru":                       {},
	"moyakuhnia.ru":                        {},
	"moyaskidka.ru":                        {},
	"moygorod-online.ru":                   {},
	"moyparnik.com":                        {},
	"mrbojikobi4.biz":                      {},
	"msk-sprawka.com":                      {},
	"mtsguru.ru":                           {},
	"muscle-factory.com.ua":                {},
	"musichallaudio.ru":                    {},
	"mwductwork.com":                       {},
	"myborder.ru":                          {},
	"mybuh.kz":                             {},
	"mycheaptraffic.com":                   {},
	"mydirtystuff.com":                     {},
	"mydoctorok.ru":                        {},
	"myecomir.com":                         {},
	"myftpupload.com":                      {},
	"myplaycity.com":                       {},
	"mysexpics.ru":                         {},
	"nachalka21.ru":                        {},
	"nakozhe.com":                          {},
	"nancyblog.top":                        {},
	"nanochskazki.ru":                      {},
	"naobumium.info":                       {},
	"narosty.com":                          {},
	"natali-forex.com":                     {},
	"natprof.ru":                           {},
	"naturalpharm.com.ua":                  {},
	"navek.by":                             {},
	"nbok.net":                             {},
	"needtosellmyhousefast.com":            {},
	"net-profits.xyz":                      {},
	"netlify.com":                          {},
	"nevapotolok.ru":                       {},
	"newsrosprom.ru":                       {},
	"newstaffadsshop.club":                 {},
	"nicola.top":                           {},
	"niki-mlt.ru":                          {},
	"ninacecillia.top":                     {},
	"nizniynovgorod.dienai.ru":             {},
	"no-rx.info":                           {},
	"nomerounddec.cf":                      {},
	"novosti-avto.ru":                      {},
	"novosti-hi-tech.ru":                   {},
	"ntdtv.ru":                             {},
	"nubuilderian.info":                    {},
	"nufaq.com":                            {},
	"o-o-11-o-o.com":                       {},
	"o-o-6-o-o.com":                        {},
	"o-o-6-o-o.ru":                         {},
	"o-o-8-o-o.com":                        {},
	"o-o-8-o-o.ru":                         {},
	"o-promyshlennosti.ru":                 {},
	"obnallpro.cc":                         {},
	"obsessionphrases.com":                 {},
	"obyavka.org.ua":                       {},
	"obzor-casino-x.online":                {},
	"obzor-casino-x.ru":                    {},
	"odiabetikah.com":                      {},
	"odsadsmobile.biz":                     {},
	"ofermerah.com":                        {},
	"office2web.com":                       {},
	"officedocuments.net":                  {},
	"ogorodnic.com":                        {},
	"okna-systems.pro":                     {},
	"okno.ooo":                             {},
	"okoshkah.com":                         {},
	"olovoley.ru":                          {},
	"one-a-plus.xyz":                       {},
	"onionhydra.net":                       {},
	"online-akbars.ru":                     {},
	"online-binbank.ru":                    {},
	"online-hit.info":                      {},
	"online-intim.com":                     {},
	"online-mkb.ru":                        {},
	"online-pharma.ru":                     {},
	"online-pochtabank.ru":                 {},
	"online-raiffeisen.ru":                 {},
	"online-sbank.ru":                      {},
	"online-templatestore.com":             {},
	"online-vostbank.ru":                   {},
	"online-vtb.ru":                        {},
	"onlinedic.net":                        {},
	"onlinetvseries.me":                    {},
	"onlinewot.ru":                         {},
	"onlywoman.org":                        {},
	"oohlivecams.com":                      {},
	"ooo-olni.ru":                          {},
	"oooh.pro":                             {},
	"optsol.ru":                            {},
	"oracle-patches.ru":                    {},
	"orakul.spb.ru":                        {},
	"osteochondrosis.ru":                   {},
	"otdbiaxaem-vmeste.ru":                 {},
	"otdyx-s-komfortom.ru":                 {},
	"ownshop.cf":                           {},
	"ozas.net":                             {},
	"pageinsider.org":                      {},
	"paidonlinesites.com":                  {},
	"painting-planet.com":                  {},
	"palma-de-sochi.ru":                    {},
	"palvira.com.ua":                       {},
	"pamjatnik.com.ua":                     {},
	"pamyatnik-spb.ru":                     {},
	"pamyatnik-tsena.ru":                   {},
	"paretto.ru":                           {},
	"parking-invest.ru":                    {},
	"partizan19.ru":                        {},
	"partnerskie-programmy.net":            {},
	"paulinho.ru":                          {},
	"pay.ru":                               {},
	"pc-services.ru":                       {},
	"penzu.xyz":                            {},
	"perform-like-alibabaity.info":         {},
	"perform-likeism-alibaba.info":         {},
	"perm.dienai.ru":                       {},
	"perper.ru":                            {},
	"petrovka-online.com":                  {},
	"petrushka-restoran.ru":                {},
	"pfrf-kabinet.ru":                      {},
	"pharm--shop.ru":                       {},
	"photo-clip.ru":                        {},
	"photokitchendesign.com":               {},
	"php-market.ru":                        {},
	"picturesmania.com":                    {},
	"pills24h.com":                         {},
	"piluli.info":                          {},
	"piratbike.ru":                         {},
	"pirelli-matador.ru":                   {},
	"piulatte.cz":                          {},
	"pizdeishn.com":                        {},
	"pizza-imperia.com":                    {},
	"pizza-tycoon.com":                     {},
	"pk-pomosch.ru":                        {},
	"pk-services.ru":                       {},
	"plagscan.com":                         {},
	"podarkilove.ru":                       {},
	"poddon-moskva.ru":                     {},
	"podemnik.pro":                         {},
	"podseka1.ru":                          {},
	"poiskzakona.ru":                       {},
	"pokupaylegko.ru":                      {},
	"polemikon.ru":                         {},
	"politika.bg":                          {},
	"polyana-skazok.org.ua":                {},
	"popads.net":                           {},
	"pops.foundation":                      {},
	"popugauka.ru":                         {},
	"popugaychiki.com":                     {},
	"porndl.org":                           {},
	"pornhive.org":                         {},
	"pornhub-forum.ga":                     {},
	"pornhub-forum.uni.me":                 {},
	"pornhub-ru.com":                       {},
	"porno-asia.com":                       {},
	"porno-chaman.info":                    {},
	"porno-gallery.ru":                     {},
	"pornobest.su":                         {},
	"pornoelita.info":                      {},
	"pornoforadult.com":                    {},
	"pornogig.com":                         {},
	"pornohd1080.online":                   {},
	"pornoklad.ru":                         {},
	"pornonik.com":                         {},
	"pornoplen.com":                        {},
	"pornosemki.info":                      {},
	"pornoslave.net":                       {},
	"portnoff.od.ua":                       {},
	"pospektr.ru":                          {},
	"posteezy.xyz":                         {},
	"potolokelekor.ru":                     {},
	"povodok-shop.ru":                      {},
	"pozdravleniya-c.ru":                   {},
	"predmety.in.ua":                       {},
	"prezidentshop.ru":                     {},
	"priceg.com":                           {},
	"pricheski-video.com":                  {},
	"primfootball.com":                     {},
	"print-technology.ru":                  {},
	"prizrn.site":                          {},
	"prlog.ru":                             {},
	"probenzo.com.ua":                      {},
	"procrafts.ru":                         {},
	"prodaemdveri.com":                     {},
	"producm.ru":                           {},
	"prodvigator.ua":                       {},
	"professionalsolutions.eu":             {},
	"profnastil-moscow.ru":                 {},
	"progressive-seo.com":                  {},
	"prointer.net.ua":                      {},
	"prom23.ru":                            {},
	"promoforum.ru":                        {},
	"promoteapps.online":                   {},
	"promotion-for99.com":                  {},
	"pron.pro":                             {},
	"prosmibank.ru":                        {},
	"prostitutki-rostova.ru.com":           {},
	"prostoacc.com":                        {},
	"psa48.ru":                             {},
	"psn-card.ru":                          {},
	"ptashkatextil.ua":                     {},
	"punch.media":                          {},
	"purchasepillsnorx.com":                {},
	"puzzleweb.ru":                         {},
	"qualitymarketzone.com":                {},
	"quickchange.cc":                       {},
	"quit-smoking.ga":                      {},
	"qwesa.ru":                             {},
	"rachelblog.online":                    {},
	"rainbirds.ru":                         {},
	"rangjued.com":                         {},
	"rank-checker.online":                  {},
	"rankings-analytics.com":               {},
	"ranksonic.info":                       {},
	"ranksonic.net":                        {},
	"ranksonic.org":                        {},
	"rapidgator-porn.ga":                   {},
	"rapidsites.pro":                       {},
	"raschtextil.com.ua":                   {},
	"raymondblog.top":                      {},
	"razborka-skoda.org.ua":                {},
	"rcb101.ru":                            {},
	"realresultslist.com":                  {},
	"recinziireale.com":                    {},
	"rednise.com":                          {},
	"redraincine.com":                      {},
	"reginanahum.top":                      {},
	"regionshop.biz":                       {},
	"reklamnoe.agency":                     {},
	"releshop.ru":                          {},
	"remkompov.ru":                         {},
	"remont-kvartirspb.com":                {},
	"remontvau.ru":                         {},
	"rent2spb.ru":                          {},
	"replica-watch.ru":                     {},
	"research.ifmo.ru":                     {},
	"resell-seo-services.com":              {},
	"resellerclub.com":                     {},
	"responsive-test.net":                  {},
	"resurs-2012.ru":                       {},
	"reversing.cc":                         {},
	"rfavon.ru":                            {},
	"rightenergysolutions.com.au":          {},
	"roof-city.ru":                         {},
	"room-mebel.ru":                        {},
	"rospromtest.ru":                       {},
	"royal-casino.online":                  {},
	"royal-casino.ru":                      {},
	"royal-casinos.online":                 {},
	"royal-casinos.ru":                     {},
	"royal-cazino.online":                  {},
	"royal-cazino.ru":                      {},
	"rspectr.com":                          {},
	"ru-lk-rt.ru":                          {},
	"ru-onion.com":                         {},
	"ru-online-sberbank.ru":                {},
	"ruinfocomp.ru":                        {},
	"rulate.ru":                            {},
	"rumamba.com":                          {},
	"rupolitshow.ru":                       {},
	"rus-lit.com":                          {},
	"rusexy.xyz":                           {},
	"ruspoety.ru":                          {},
	"russian-postindex.ru":                 {},
	"russian-translator.com":               {},
	"russkie-sochineniya.ru":               {},
	"rustag.ru":                            {},
	"rutor.group":                          {},
	"rxshop.md":                            {},
	"rybalka-opt.ru":                       {},
	"s-forum.biz":                          {},
	"s-luna.me":                            {},
	"sad-torg.com.ua":                      {},
	"sady-urala.ru":                        {},
	"saltspray.ru":                         {},
	"samanthablog.online":                  {},
	"samara-airport.com":                   {},
	"samara-comfort.ru":                    {},
	"samchist.ru":                          {},
	"samlaurabrown.top":                    {},
	"samogonius.ru":                        {},
	"sanjosestartups.com":                  {},
	"santaren.by":                          {},
	"santasgift.ml":                        {},
	"santehnovich.ru":                      {},
	"sapaship.ru":                          {},
	"sauna-v-ufe.ru":                       {},
	"sauni-lipetsk.ru":                     {},
	"sauni-moskva.ru":                      {},
	"savetubevideo.com":                    {},
	"savetubevideo.info":                   {},
	"scansafe.net":                         {},
	"scat.porn":                            {},
	"screentoolkit.com":                    {},
	"scripted.com":                         {},
	"search-error.com":                     {},
	"searchencrypt.com":                    {},
	"security-corporation.com.ua":          {},
	"sel-hoz.com":                          {},
	"selfhotdog.com":                       {},
	"sell-fb-group-here.com":               {},
	"semalt.com":                           {},
	"semaltmedia.com":                      {},
	"seo-2-0.com":                          {},
	"seo-platform.com":                     {},
	"seo-services-b2b.com":                 {},
	"seo-services-wordpress.com":           {},
	"seo-smm.kz":                           {},
	"seo-tips.top":                         {},
	"seoanalyses.com":                      {},
	"seobook.top":                          {},
	"seocheckupx.com":                      {},
	"seocheckupx.net":                      {},
	"seoexperimenty.ru":                    {},
	"seojokes.net":                         {},
	"seopub.net":                           {},
	"seoservices2018.com":                  {},
	"serialsx.ru":                          {},
	"sexpornotales.net":                    {},
	"sexreliz.com":                         {},
	"sexsaoy.com":                          {},
	"sexuria.net":                          {},
	"sexyali.com":                          {},
	"sexyteens.hol.es":                     {},
	"shagtomsk.ru":                         {},
	"share-buttons-for-free.com":           {},
	"share-buttons.xyz":                    {},
	"sharebutton.io":                       {},
	"sharebutton.net":                      {},
	"sharebutton.to":                       {},
	"sheki-spb.ru":                         {},
	"shnyagi.net":                          {},
	"shop2hydra.com":                       {},
	"shop4fit.ru":                          {},
	"shopfishing.com.ua":                   {},
	"shoppingmiracles.co.uk":               {},
	"shoprybalka.ru":                       {},
	"shops-ru.ru":                          {},
	"shopsellcardsdumps.com":               {},
	"shtaketniki.ru":                       {},
	"shulepov.ru":                          {},
	"sib-kukla.ru":                         {},
	"sibecoprom.ru":                        {},
	"sibkukla.ru":                          {},
	"sign-service.ru":                      {},
	"silvergull.ru":                        {},
	"sim-dealer.ru":                        {},
	"similarmoviesdb.com":                  {},
	"simoncinicancertherapy.com":           {},
	"simple-share-buttons.com":             {},
	"sinhronperevod.ru":                    {},
	"site-auditor.online":                  {},
	"site5.com":                            {},
	"siteripz.net":                         {},
	"sitesadd.com":                         {},
	"sitevaluation.org":                    {},
	"skidku.org.ua":                        {},
	"skinali.com":                          {},
	"skinali.photo-clip.ru":                {},
	"sladkoevideo.com":                     {},
	"sledstvie-veli.net":                   {},
	"slftsdybbg.ru":                        {},
	"slkrm.ru":                             {},
	"slomm.ru":                             {},
	"slotron.com":                          {},
	"slow-website.xyz":                     {},
	"smailik.org":                          {},
	"smartphonediscount.info":              {},
	"smt4.ru":                              {},
	"snabs.kz":                             {},
	"snaiper-bg.net":                       {},
	"snegozaderzhatel.ru":                  {},
	"snip.to":                              {},
	"snip.tw":                              {},
	"soaksoak.ru":                          {},
	"sochi-3d.ru":                          {},
	"social-button.xyz":                    {},
	"social-buttons-ii.xyz":                {},
	"social-buttons.com":                   {},
	"social-traffic-1.xyz":                 {},
	"social-traffic-2.xyz":                 {},
	"social-traffic-3.xyz":                 {},
	"social-traffic-4.xyz":                 {},
	"social-traffic-5.xyz":                 {},
	"social-traffic-7.xyz":                 {},
	"social-widget.xyz":                    {},
	"socialbuttons.xyz":                    {},
	"socialseet.ru":                        {},
	"socialtrade.biz":                      {},
	"sohoindia.net":                        {},
	"solitaire-game.ru":                    {},
	"solnplast.ru":                         {},
	"sosdepotdebilan.com":                  {},
	"souvenirua.com":                       {},
	"sovetogorod.ru":                       {},
	"sovetskie-plakaty.ru":                 {},
	"sowhoz.ru":                            {},
	"soyuzexpedition.ru":                   {},
	"sp-laptop.ru":                         {},
	"sp-zakupki.ru":                        {},
	"space2019.top":                        {},
	"spain-poetry.com":                     {},
	"spartania.com.ua":                     {},
	"spb-plitka.ru":                        {},
	"spb-scenar.ru":                        {},
	"specstroy36.ru":                       {},
	"speedup-my.site":                      {},
	"spin2016.cf":                          {},
	"sportobzori.ru":                       {},
	"sportwizard.ru":                       {},
	"spravka130.ru":                        {},
	"spravkavspb.net":                      {},
	"spravkavspb.work":                     {},
	"sprawka-help.com":                     {},
	"spy-app.info":                         {},
	"squarespace.top":                      {},
	"sribno.net":                           {},
	"sssexxx.net":                          {},
	"ssve.ru":                              {},
	"sta-grand.ru":                         {},
	"stat.lviv.ua":                         {},
	"stavimdveri.ru":                       {},
	"steame.ru":                            {},
	"stiralkovich.ru":                      {},
	"stocktwists.com":                      {},
	"stoletie.ru":                          {},
	"stoliar.org":                          {},
	"stomatologi.moscow":                   {},
	"stop-nark.ru":                         {},
	"stop-zavisimost.com":                  {},
	"store-rx.com":                         {},
	"strady.org.ua":                        {},
	"stream-tds.com":                       {},
	"stroi-24.ru":                          {},
	"stroy-matrix.ru":                      {},
	"stroyalp.ru":                          {},
	"stroyka-gid.ru":                       {},
	"stroyka47.ru":                         {},
	"studentguide.ru":                      {},
	"stylecaster.top":                      {},
	"su1ufa.ru":                            {},
	"success-seo.com":                      {},
	"sudachitravel.com":                    {},
	"sundrugstore.com":                     {},
	"super-seo-guru.com":                   {},
	"superiends.org":                       {},
	"supermama.top":                        {},
	"supermodni.com.ua":                    {},
	"superoboi.com.ua":                     {},
	"superslots-casino.online":             {},
	"superslots-casino.site":               {},
	"superslots-cazino.online":             {},
	"superslots-cazino.site":               {},
	"superslotz-casino.site":               {},
	"superslotz-cazino.site":               {},
	"supervesti.ru":                        {},
	"svadba-teplohod.ru":                   {},
	"svensk-poesi.com":                     {},
	"svet-depo.ru":                         {},
	"svetka.info":                          {},
	"svetoch.moscow":                       {},
	"svoimi-rukamy.com":                    {},
	"svs-avto.com":                         {},
	"swaplab.io":                           {},
	"sweet.tv":                             {},
	"t-machinery.ru":                       {},
	"t-rec.su":                             {},
	"taihouse.ru":                          {},
	"tam-gde-more.ru":                      {},
	"tamada69.com":                         {},
	"tammyblog.online":                     {},
	"targetpay.nl":                         {},
	"tattoo-stickers.ru":                   {},
	"tattooha.com":                         {},
	"td-abs.ru":                            {},
	"td-l-market.ru":                       {},
	"td-perimetr.ru":                       {},
	"tdbatik.com":                          {},
	"tds-west.ru":                          {},
	"technika-remont.ru":                   {},
	"tedxrj.com":                           {},
	"teman.com.ua":                         {},
	"tentcomplekt.ru":                      {},
	"teplohod-gnezdo.ru":                   {},
	"teplokomplex.ru":                      {},
	"teresablog.top":                       {},
	"tesla-audit.ru":                       {},
	"texnika.com.ua":                       {},
	"tgsubs.com":                           {},
	"tgtclick.com":                         {},
	"thaimassage-slon.ru":                  {},
	"thaoduoctoc.com":                      {},
	"the-world.ru":                         {},
	"theautoprofit.ml":                     {},
	"theguardlan.com":                      {},
	"thelotter.su":                         {},
	"thesensehousehotel.com":               {},
	"thesmartsearch.net":                   {},
	"timmy.by":                             {},
	"tocan.biz":                            {},
	"tocan.com.ua":                         {},
	"tokshow.online":                       {},
	"tomck.com":                            {},
	"top-gan.ru":                           {},
	"top-instagram.info":                   {},
	"top-l2.com":                           {},
	"top1-seo-service.com":                 {},
	"top10-online-games.com":               {},
	"top10-way.com":                        {},
	"toposvita.com":                        {},
	"topquality.cf":                        {},
	"topseoservices.co":                    {},
	"torobrand.com":                        {},
	"torrentgamer.net":                     {},
	"torrentred.games":                     {},
	"track-rankings.online":                {},
	"tracker24-gps.ru":                     {},
	"trafers.com":                          {},
	"traffic-cash.xyz":                     {},
	"traffic2cash.org":                     {},
	"traffic2cash.xyz":                     {},
	"traffic2money.com":                    {},
	"trafficgenius.xyz":                    {},
	"trafficmonetize.org":                  {},
	"trafficmonetizer.org":                 {},
	"transit.in.ua":                        {},
	"traphouselatino.net":                  {},
	"travel-semantics.com":                 {},
	"tricolortv-online.com":                {},
	"trieste.io":                           {},
	"trion.od.ua":                          {},
	"truebeauty.cc":                        {},
	"tsatu.edu.ua":                         {},
	"tsc-koleso.ru":                        {},
	"tuningdom.ru":                         {},
	"tvfru.org":                            {},
	"twsufa.ru":                            {},
	"ua.tc":                                {},
	"uasb.ru":                              {},
	"ucanfly.ru":                           {},
	"ucoz.ru":                              {},
	"udav.net":                             {},
	"ufa.dienai.ru":                        {},
	"ufolabs.net":                          {},
	"uginekologa.com":                      {},
	"ukrainian-poetry.com":                 {},
	"ukrcargo.com":                         {},
	"ukrtvory.in.ua":                       {},
	"ul-potolki.ru":                        {},
	"undergroundcityphoto.com":             {},
	"unibus.su":                            {},
	"univerfiles.com":                      {},
	"unlimitdocs.net":                      {},
	"unpredictable.ga":                     {},
	"uptime-as.net":                        {},
	"uptime-eu.net":                        {},
	"uptime-us.net":                        {},
	"uptime.com":                           {},
	"uptimechecker.com":                    {},
	"urblog.xyz":                           {},
	"uruto.ru":                             {},
	"uslugi-tatarstan.ru":                  {},
	"uyutmaster73.ru":                      {},
	"uzpaket.com":                          {},
	"uzungil.com":                          {},
	"v-casino.ru":                          {},
	"v-casino.site":                        {},
	"v-cazino.online":                      {},
	"v-cazino.ru":                          {},
	"vaderenergy.ru":                       {},
	"valid-cc.com":                         {},
	"validccseller.com":                    {},
	"validus.pro":                          {},
	"vape-x.ru":                            {},
	"vardenafil20.com":                     {},
	"varikozdok.ru":                        {},
	"vbikse.com":                           {},
	"vchulkah.net":                         {},
	"veles.shop":                           {},
	"veloland.in.ua":                       {},
	"ventopt.by":                           {},
	"veronicablog.top":                     {},
	"vescenter.ru":                         {},
	"veselokloun.ru":                       {},
	"vesnatehno.com":                       {},
	"vetbvc.ru":                            {},
	"vezdevoz.com.ua":                      {},
	"vgoloveboli.net":                      {},
	"viagra-soft.ru":                       {},
	"video--production.com":                {},
	"video-woman.com":                      {},
	"videochat.world":                      {},
	"videos-for-your-business.com":         {},
	"videotop.biz":                         {},
	"viel.su":                              {},
	"viktoria-center.ru":                   {},
	"virtual-zaim.ru":                      {},
	"virtualbb.com":                        {},
	"vk.com":                               {},
	"vkonche.com":                          {},
	"vksex.ru":                             {},
	"vladtime.ru":                          {},
	"vodabur.by":                           {},
	"vodaodessa.com":                       {},
	"vodkoved.ru":                          {},
	"volond.com":                           {},
	"vpdr.pl":                              {},
	"vsdelke.ru":                           {},
	"vseigru.one":                          {},
	"vseigry.fun":                          {},
	"vseprobrak.ru":                        {},
	"vulkan-oficial.com":                   {},
	"vzheludke.com":                        {},
	"vzubah.com":                           {},
	"vzube.com":                            {},
	"vzubkah.com":                          {},
	"w2mobile-za.com":                      {},
	"w3javascript.com":                     {},
	"wakeupseoconsultant.com":              {},
	"wallet-prlzn.space":                   {},
	"wallinside.top":                       {},
	"wallpaperdesk.info":                   {},
	"wallpapers-all.com":                   {},
	"warmex.com.ua":                        {},
	"wave-games.ru":                        {},
	"wdss.com.ua":                          {},
	"we-ping-for-youic.info":               {},
	"web-revenue.xyz":                      {},
	"webalex.pro":                          {},
	"webmaster-traffic.com":                {},
	"webmonetizer.net":                     {},
	"website-analytics.online":             {},
	"website-analyzer.info":                {},
	"website-speed-check.site":             {},
	"website-speed-checker.site":           {},
	"websites-reviews.com":                 {},
	"websocial.me":                         {},
	"weburlopener.com":                     {},
	"weebly.com":                           {},
	"weightbelts.ru":                       {},
	"wfdesigngroup.com":                    {},
	"wmasterlead.com":                      {},
	"woman-orgasm.ru":                      {},
	"wordpress-crew.net":                   {},
	"wordpresscore.com":                    {},
	"workius.ru":                           {},
	"workona.com":                          {},
	"works.if.ua":                          {},
	"worldmed.info":                        {},
	"worldofbtc.com":                       {},
	"wpnull.org":                           {},
	"wrc-info.ru":                          {},
	"wufak.com":                            {},
	"ww2awards.info":                       {},
	"www-lk-rt.ru":                         {},
	"www.gelendzhic.ru":                    {},
	"x-lime.com":                           {},
	"x-lime.net":                           {},
	"x5market.ru":                          {},
	"xaker26.net":                          {},
	"xexe.club":                            {},
	"xkaz.org":                             {},
	"xn-------53dbcapga5atlplfdm6ag1ab1bvehl0b7toa0k.xn--p1ai":         {},
	"xn------6cdbciescapvf0a8bibwx0a1bu.xn--90ais":                     {},
	"xn-----6kcamwewcd9bayelq.xn--p1ai":                                {},
	"xn-----7kcaaxchbbmgncr7chzy0k0hk.xn--p1ai":                        {},
	"xn-----clckdac3bsfgdft3aebjp5etek.xn--p1ai":                       {},
	"xn----7sbabb9a1b7bddgm6a1i.xn--p1ai":                              {},
	"xn----7sbabhjc3ccc5aggbzfmfi.xn--p1ai":                            {},
	"xn----7sbabhv4abd8aih6bb7k.xn--p1ai":                              {},
	"xn----7sbabm1ahc4b2aqff.su":                                       {},
	"xn----7sbabn5abjehfwi8bj.xn--p1ai":                                {},
	"xn----7sbbpe3afguye.xn--p1ai":                                     {},
	"xn----7sbho2agebbhlivy.xn--p1ai":                                  {},
	"xn----8sbaki4azawu5b.xn--p1ai":                                    {},
	"xn----8sbarihbihxpxqgaf0g1e.xn--80adxhks":                         {},
	"xn----8sbbjimdeyfsi.xn--p1ai":                                     {},
	"xn----8sbhefaln6acifdaon5c6f4axh.xn--p1ai":                        {},
	"xn----8sblgmbj1a1bk8l.xn----161-4vemb6cjl7anbaea3afninj.xn--p1ai": {},
	"xn----8sbowe2akbcd4h.xn--p1ai":                                    {},
	"xn----btbdvdh4aafrfciljm6k.xn--p1ai":                              {},
	"xn----ctbbcjd3dbsehgi.xn--p1ai":                                   {},
	"xn----ctbfcdjl8baejhfb1oh.xn--p1ai":                               {},
	"xn----ctbigni3aj4h.xn--p1ai":                                      {},
	"xn----dtbffp5aagjgfm.xn--p1ai":                                    {},
	"xn----ftbeoaiyg1ak1cb7d.xn--p1ai":                                 {},
	"xn----itbbudqejbfpg3l.com":                                        {},
	"xn----jtbjfcbdfr0afji4m.xn--p1ai":                                 {},
	"xn--80aaajkrncdlqdh6ane8t.xn--p1ai":                               {},
	"xn--80aabcsc3bqirlt.xn--p1ai":                                     {},
	"xn--80aanaardaperhcem4a6i.com":                                    {},
	"xn--80adaggc5bdhlfamsfdij4p7b.xn--p1ai":                           {},
	"xn--80adgcaax6acohn6r.xn--p1ai":                                   {},
	"xn--80aeb6argv.xn--p1ai":                                          {},
	"xn--80ahdheogk5l.xn--p1ai":                                        {},
	"xn--90acenikpebbdd4f6d.xn--p1ai":                                  {},
	"xn--90acjmaltae3acm.xn--p1acf":                                    {},
	"xn--c1acygb.xn--p1ai":                                             {},
	"xn--d1abj0abs9d.in.ua":                                            {},
	"xn--d1aifoe0a9a.top":                                              {},
	"xn--e1aaajzchnkg.ru.com":                                          {},
	"xn--e1aahcgdjkg4aeje6j.kz":                                        {},
	"xn--e1agf4c.xn--80adxhks":                                         {},
	"xpert.com.ua":                                                     {},
	"xtraffic.plus":                                                    {},
	"xtrafficplus.com":                                                 {},
	"xxxhamster.me":                                                    {},
	"xz618.com":                                                        {},
	"yaderenergy.ru":                                                   {},
	"yes-com.com":                                                      {},
	"yes-do-now.com":                                                   {},
	"yhirurga.ru":                                                      {},
	"ykecwqlixx.ru":                                                    {},
	"yodse.io":                                                         {},
	"yoga4.ru":                                                         {},
	"yougame.biz":                                                      {},
	"youhack.info":                                                     {},
	"youporn-forum.ga":                                                 {},
	"youporn-forum.uni.me":                                             {},
	"youporn-ru.com":                                                   {},
	"your-good-links.com":                                              {},
	"your-tales.ru":                                                    {},
	"yourserverisdown.com":                                             {},
	"yur-p.ru":                                                         {},
	"yurcons.pro":                                                      {},
	"yuristproffi.ru":                                                  {},
	"zagadki.in.ua":                                                    {},
	"zahodi2hydra.net":                                                 {},
	"zahvat.ru":                                                        {},
	"zakaznoy.com.ua":                                                  {},
	"zakis-azota24.ru":                                                 {},
	"zamolotkom.ru":                                                    {},
	"zapnado.ru":                                                       {},
	"zarabotat-v-internete.biz":                                        {},
	"zastroyka.org":                                                    {},
	"zavod-gm.ru":                                                      {},
	"zdm-auto.com":                                                     {},
	"zdm-auto.ru":                                                      {},
	"zdorovie-nogi.info":                                               {},
	"zelena-mriya.com.ua":                                              {},
	"zhoobintravel.com":                                                {},
	"zoominfo.com":                                                     {},
	"zot.moscow":                                                       {},
	"zt-m.ru":                                                          {},
	"zvetki.ru":                                                        {},
	"zvooq.eu":                                                         {},
	"zvuker.net":                                                       {},
}
